<?php
/**
 * nesiapress functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package nesiapress
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '2.0.7' );
}

if ( ! function_exists( 'nesiapress_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function nesiapress_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on nesiapress, use a find and replace
		 * to change 'nesiapress' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'nesiapress', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'nesiapress' ),
				'footer' => esc_html( 'Footer Menu', 'nesiapress' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'nesiapress_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'nesiapress_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nesiapress_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nesiapress_content_width', 640 );
}
add_action( 'after_setup_theme', 'nesiapress_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function nesiapress_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'nesiapress' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'nesiapress' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'nesiapress_widgets_init' );

/**
 * Get mix compiled asset.
 *
 * @param string $path The path to the asset.
 *
 * @return string
 */
function nesiapress_get_mix_compiled_asset_url( $path ) {
	$path                = '/' . $path;
	$stylesheet_dir_uri  = get_stylesheet_directory_uri();
	$stylesheet_dir_path = get_stylesheet_directory();

	if ( ! file_exists( $stylesheet_dir_path . '/mix-manifest.json' ) ) {
		return $stylesheet_dir_uri . $path;
	}

	$mix_file_path = file_get_contents( $stylesheet_dir_path . '/mix-manifest.json' );
	$manifest      = json_decode( $mix_file_path, true );
	$asset_path    = ! empty( $manifest[ $path ] ) ? $manifest[ $path ] : $path;

	return $stylesheet_dir_uri . $asset_path;
}

/**
 * Enqueue scripts and styles.
 */
function nesiapress_scripts() {
	wp_enqueue_style( 'nesiapress-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'nesiapress-style', 'rtl', 'replace' );
	
	wp_enqueue_style( 'nesiapress', nesiapress_get_mix_compiled_asset_url( 'css/app.css' ), array(), _S_VERSION );
	
	wp_enqueue_script( 'nesiapress', nesiapress_get_mix_compiled_asset_url( 'js/app.js' ), array( 'jquery' ), _S_VERSION );

	wp_enqueue_script( 'nesiapress-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	wp_localize_script( 
		'nesiapress-navigation',
		'nesiapressReader',
		array(
			'expand'		=> __('expand child menu', 'nesiapress'),
			'collapse'	=> __('collapse child menu', 'nesiapress'),
		)
	);

	// Adding Alpine.js support
	if(defined('ALPINEJS')){
		
		wp_enqueue_script( 'alpinejs', '//unpkg.com/alpinejs', array(), _S_VERSION );
	}

	// Import mobile menu button
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'nesiapress_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Add option 'li_class' to 'wp_nav_menu'.
 *
 * @param string  $classes String of classes.
 * @param mixed   $item The curren item.
 * @param WP_Term $args Holds the nav menu arguments.
 *
 * @return array
 */
function nesiapress_add_li_class($classes, $item, $args, $depth ) {
	if ( isset( $args->li_class ) ) {
		$classes[] = $args->li_class;
	}

	if ( isset( $args->{"li_class_$depth"} ) ) {
		$classes[] = $args->{"li_class_$depth"};
	}

	return $classes;
}

add_filter( 'navigation_menu_list', 'nesiapress_add_li_class', 10, 4 );

/**
 * Add option 'submenu_class' to 'wp_nav_menu'.
 *
 * @param string  $classes String of classes.
 * @param mixed   $item The curren item.
 * @param WP_Term $args Holds the nav menu arguments.
 *
 * @return array
 */
function nesiapress_add_submenu( $classes, $args, $depth ) {
	if ( isset( $args->submenu_class ) ) {
		$classes[] = $args->submenu_class;
	}

	if ( isset( $args->{"submenu_class_$depth"} ) ) {
		$classes[] = $args->{"submenu_class_$depth"};
	}

	return $classes;
}

add_filter( 'navigation_submenu', 'nesiapress_add_submenu', 10, 3 );

/**
 * Custom template pagination for this theme.
 */
function the_np_posts_pagination($args = [], $class = 'pagination') {

	if ($GLOBALS['wp_query']->max_num_pages <= 1) return;

	$args = wp_parse_args( $args, [
		'mid_size'           => 2,
		'prev_next'          => false,
		'prev_text'          => __('Older posts', 'nesiapress'),
		'next_text'          => __('Newer posts', 'nesiapress'),
		'screen_reader_text' => __('Posts pagination', 'nesiapress'),
	]);

	$links     = paginate_links($args);
	$next_link = get_previous_posts_link($args['next_text']);
	$prev_link = get_next_posts_link($args['prev_text']);
	$template  = apply_filters( 'the_np_posts_navigation_template', '
	<div class="np-pagination">
		<div class="np-container">
			<nav class="navigation %1$s" role="navigation">
				<h2 class="screen-reader-text">%2$s</h2>
				<div class="nav-links"><div class="nav-previous">%3$s</div><div class="page-numbers-container">%4$s</div><div class="nav-next">%5$s</div></div>
			</nav>
		</div>
	</div>', $args, $class);

	echo sprintf($template, $class, $args['screen_reader_text'], $prev_link, $links, $next_link);
}

/**
 *  Custom template category at grid post for this theme.
 */
if ( ! function_exists( 'nesiapress_cat_links' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function nesiapress_cat_links() {
		// Hide tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'nesiapress' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( '%1$s', 'nesiapress' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}
	}
endif;

/**
 *  Custom template category at single post for this theme.
 */
if ( ! function_exists( 'nesiapress_entry_cat_links' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function nesiapress_entry_cat_links() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'nesiapress' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="entry-cat-links">' . esc_html__( '%1$s', 'nesiapress' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}
	}
endif;

/**
 *  Template article post date for this theme.
 */
if ( ! function_exists( 'nesiapress_post_update' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function nesiapress_post_update() {
		$time_string = '<time class="entry-date published updated" itemprop="datePublished" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( '%s', 'post date', 'nesiapress' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

/**
 *  Template article post author for this theme.
 */
if ( ! function_exists( 'nesiapress_meta_author' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function nesiapress_meta_author() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( ' %s', 'post author', 'nesiapress' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // phpc s:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;